Enum WireMessage

pub enum WireMessage {
    Signal {
        data: Vec<u8>,
    },
    Authenticate {
        data: Vec<u8>,
    },
    Request {
        id: u64,
        data: Vec<u8>,
    },
    Response {
        id: u64,
        data: Option<Vec<u8>>,
    },
}
The messages actually sent over the wire by this library. If you want to implement your own server or client you will need this type or be able to serialize / deserialize it.

Variants



Signal

A message without a response.

Fields

data: Vec<u8>

Actual bytes of the message serialized as message pack.



Authenticate

An authentication message, sent by the client if the server requires it.

Fields

data: Vec<u8>

Actual bytes of the message serialized as message pack.



Request

A request that requires a response.

Fields

id: u64

The id of this request.

data: Vec<u8>

Actual bytes of the message serialized as message pack.



Response

The response to a request.

Fields

id: u64

The id of the request that this response is for.

data: Option<Vec<u8>>

Actual bytes of the message serialized as message pack.